@@ -356,6 +356,8 @@ class AquaLogic():
             _LOGGER.info("socket timeout")
         except serial.SerialTimeoutException:
             _LOGGER.info("serial timeout")
+        except IndexError:
+            _LOGGER.info("index error")
         except EOFError:
             _LOGGER.info("eof")
 
